@@ -1,4 +1,4 @@
-//$Id: dndwindow.cc 449 2005-11-16 20:22:00Z  $ -*- c++ -*-
+//$Id: dndwindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -36,9 +36,10 @@ DnDWindow::DnDWindow()
 
   //Make m_Button_Drag a DnD drag source:
   m_Button_Drag.drag_source_set(listTargets);
-		
+
   //Connect signals:
-  m_Button_Drag.signal_drag_data_get().connect( sigc::mem_fun(*this, &DnDWindow::on_button_drag_data_get));
+  m_Button_Drag.signal_drag_data_get().connect(sigc::mem_fun(*this,
+              &DnDWindow::on_button_drag_data_get));
 
   m_HBox.pack_start(m_Button_Drag);
 
@@ -48,7 +49,8 @@ DnDWindow::DnDWindow()
   m_Label_Drop.drag_dest_set(listTargets);
 
   //Connect signals:
-  m_Label_Drop.signal_drag_data_received().connect( sigc::mem_fun(*this, &DnDWindow::on_label_drop_drag_data_received) );
+  m_Label_Drop.signal_drag_data_received().connect(sigc::mem_fun(*this,
+              &DnDWindow::on_label_drop_drag_data_received) );
 
   m_HBox.pack_start(m_Label_Drop);
 
@@ -59,16 +61,23 @@ DnDWindow::~DnDWindow()
 {
 }
 
-void DnDWindow::on_button_drag_data_get(const Glib::RefPtr<Gdk::DragContext>&, Gtk::SelectionData& selection_data, guint, guint)
+void DnDWindow::on_button_drag_data_get(
+        const Glib::RefPtr<Gdk::DragContext>&,
+        Gtk::SelectionData& selection_data, guint, guint)
 {
-  selection_data.set(selection_data.get_target(), 8 /* 8 bits format */, (const guchar*)"I'm Data!", 9 /* the length of I'm Data! in bytes */);
+  selection_data.set(selection_data.get_target(), 8 /* 8 bits format */,
+          (const guchar*)"I'm Data!",
+          9 /* the length of I'm Data! in bytes */);
 }
 
-void DnDWindow::on_label_drop_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int, int, const Gtk::SelectionData& selection_data, guint, guint time)
-{ 
+void DnDWindow::on_label_drop_drag_data_received(
+        const Glib::RefPtr<Gdk::DragContext>& context, int, int,
+        const Gtk::SelectionData& selection_data, guint, guint time)
+{
   if ((selection_data.get_length() >= 0) && (selection_data.get_format() == 8))
   {
-    std::cout << "Received \"" << selection_data.get_data_as_string() << "\" in label " << std::endl;
+    std::cout << "Received \"" << selection_data.get_data_as_string()
+        << "\" in label " << std::endl;
   }
 
   context->drag_finish(false, false, time);
