@@ -1,4 +1,4 @@
-//$Id: main.cc 705 2006-07-19 02:55:32Z jjongsma $ -*- c++ -*-
+//$Id: main.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -22,11 +22,14 @@ int main(int argc, char *argv[])
 {
   Gtk::Main kit(argc, argv);
 
-  Glib::RefPtr<Gtk::StatusIcon> status_icon = Gtk::StatusIcon::create(Gtk::Stock::HELP); //Use your own icon in real life.
+  //Use your own icon in real life.
+  Glib::RefPtr<Gtk::StatusIcon> status_icon =
+      Gtk::StatusIcon::create(Gtk::Stock::HELP);
   status_icon->set_tooltip("gtkmm StatusIcon example tooltip.");
 
   //Show a window:
-  //The program will stop, and the status icon will disappear, when the window is closed.
+  //The program will stop, and the status icon will disappear, when the window
+  //is closed.
   Gtk::Window window;
   window.set_title("gtkmm StatusIcon example.");
   window.set_default_size(300, 300);
